@@ -18,6 +18,7 @@ pooled=True and be sure to close the session when done with a thread.
 from __future__ import unicode_literals
 
 import datetime
+import unicodedata
 from sqlalchemy.exc import DBAPIError
 
 from . import DublinCore
@@ -101,13 +102,12 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             for key in args:
                 setattr(s, key, args[key])
             return s
-        
+
         book = self.load_book(ebook)
         if not book:
             return
 
         # Load DublinCore from PG database.
-        session = self.get_my_session()
         if self.release_date == datetime.date.min:
             self.release_date = book.release_date
         self.downloads = book.downloads
@@ -131,9 +131,9 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
                 self.title_file_as = self.title_file_as[0].upper() +\
                     self.title_file_as[1:]
                 debug("Title: %s", self.title)
-            elif marc.code == '206':                
+            elif marc.code == '206':
                 self.alt_title = marc.text
-            elif marc.code == '260':                
+            elif marc.code == '260':
                 self.pubinfo.years = [('copyright', marc.text)]
             elif marc.code == '500':
                 self.notes = marc.text
@@ -261,7 +261,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             session.rollback()
 
     def save(self, updatemode=0):
-        """ 
+        """
             updatemode = 0 : initial metadata creation; won't change an existing book
             updatemode = 1 : change metadata for an existing book
         """
@@ -273,7 +273,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             # this has not yet been loaded from a database or pre-assigned an id
             info("loading book for project gutenberg id %s", self.project_gutenberg_id)
             self.load_or_create_book(self.project_gutenberg_id)
-            
+
 
         session = self.get_my_session()
         if self.book.updatemode != updatemode:
@@ -353,7 +353,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
     def add_authors(self, book):
         if len(book.authors) > 0:
             info("book already has authors.")
-            if not len(self.authors):
+            if len(self.authors) == 0:
                 return False
             if self.authors is book.authors:
                 return False
@@ -377,17 +377,40 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
 
     def get_or_create_author(self, name, birthdate=None, deathdate=None):
+        ''' look for author in db matching name '''
+
+        def is_good_match(db_str, name):
+            ''' make sure we're not matching in the middle of a name '''
+            if name not in db_str:
+                return False
+            [before, after] = db_str.split(name, 1)
+            if len(before) > 0 and unicodedata.category(before[-1])[0] == 'L':
+                return False
+            if len(after) > 0 and unicodedata.category(after[0])[0] == 'L':
+                return False
+            return True
+
         session = self.get_my_session()
         like_author = '%%%s%%' % name
         # get an author by matching name
-        author = session.query(Author).where(
-            Author.name.ilike(like_author)).order_by(Author.id).first()
-        if not author:
-            author = session.query(Author).join(Alias.author).where(
-                Alias.alias.ilike(like_author)).order_by(Alias.fk_authors).first()
-        if not author:
-            author = Author(name=name, birthdate=birthdate, deathdate=deathdate)
-            session.add(author)
+        match_authors = session.query(Author).where(
+            Author.name.ilike(like_author)).order_by(Author.id).all()
+
+        for author in match_authors:
+            if is_good_match(author.name, name):
+                return author
+
+        if len(match_authors) == 0:
+            match_aliases = session.query(Alias).where(
+                Alias.alias.ilike(like_author)).order_by(Alias.pk).all()
+
+            for alias in match_aliases:
+                if is_good_match(alias.alias, name):
+                    return alias.author
+
+        # no match in database
+        author = Author(name=name, birthdate=birthdate, deathdate=deathdate)
+        session.add(author)
         return author
 
 
